## cdist-type__consul(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__consul - install consul

## 2. DESCRIPTION

Downloads and installs the consul binary from https://dl.bintray.com/mitchellh/consul. Note that the consul binary is downloaded on the server (the machine running cdist) and then deployed to the target host using the __file type.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

state
  either present or absent. Defaults to present
version
  which version of consul to install. See ./files/versions for a list of supported versions. Defaults to the latest known version.

## 5. EXAMPLES

    # just install using defaults
    __consul

    # specific version
    __consul \
       --version 0.4.1

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2015 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).